@@ -4,12 +4,7 @@ import os
 import textwrap
 from enum import Enum
 from io import BytesIO
-from typing import (
-    Optional,
-    Tuple,
-    Union,
-    TYPE_CHECKING
-)
+from typing import Optional, Tuple, Union, TYPE_CHECKING
 
 import PIL
 import PIL.ImageShow
@@ -29,7 +24,7 @@ class ImageManager:
 
     @staticmethod
     def load_asset(name: str) -> str:
-        return os.path.join(os.path.dirname(__file__), 'assets', name)
+        return os.path.join(os.path.dirname(__file__), "assets", name)
 
     @staticmethod
     async def make_request(url: str) -> Optional[bytes]:
@@ -39,15 +34,15 @@ class ImageManager:
 
     @classmethod
     async def convert_image(cls, url: str) -> Image:
-        return PIL.Image.open(BytesIO(await cls.make_request(url))).convert('RGBA')
+        return PIL.Image.open(BytesIO(await cls.make_request(url))).convert("RGBA")
 
     @classmethod
     def human_format(cls, num):
         original_num = num
 
-        num = float('{:.3g}'.format(num))
+        num = float("{:.3g}".format(num))
         magnitude = 0
-        matches = ['', 'K', 'M', 'B', 'T', 'Qua', 'Qui']
+        matches = ["", "K", "M", "B", "T", "Qua", "Qui"]
         while abs(num) >= 1000:
             if magnitude >= 5:
                 break
@@ -56,17 +51,21 @@ class ImageManager:
             num /= 1000.0
 
         try:
-            return '{}{}'.format('{:f}'.format(num).rstrip('0').rstrip('.'), matches[magnitude])
+            return "{}{}".format(
+                "{:f}".format(num).rstrip("0").rstrip("."), matches[magnitude]
+            )
         except IndexError:
             return original_num
 
     @staticmethod
-    def multiline_text(card: ImageDraw,
-                       text: str,
-                       font: ImageFont,
-                       text_color: Tuple[int, int, int],
-                       start_height: Union[int, float],
-                       width: int):
+    def multiline_text(
+        card: ImageDraw,
+        text: str,
+        font: ImageFont,
+        text_color: Tuple[int, int, int],
+        start_height: Union[int, float],
+        width: int,
+    ):
         draw = ImageDraw.Draw(card)
         image_width, image_height = card.size
 
@@ -75,24 +74,35 @@ class ImageManager:
 
         for line in lines:
             line_width, line_height = font.getsize(line)
-            draw.text(((image_width - line_width) / 2, y_text), line, font=font, fill=text_color)
+            draw.text(
+                ((image_width - line_width) / 2, y_text),
+                line,
+                font=font,
+                fill=text_color,
+            )
             y_text += line_height
 
-    async def draw_profile_picture(self,
-                                   card: Image,
-                                   member: discord.Member,
-                                   location: Tuple[int, int],
-                                   size: int = 180,
-                                   outline_thickness: int = 5,
-                                   status: bool = True,
-                                   outline_color: Tuple[int, int, int] = (255, 255, 255)):
+    async def draw_profile_picture(
+        self,
+        card: Image,
+        member: discord.Member,
+        location: Tuple[int, int],
+        size: int = 180,
+        outline_thickness: int = 5,
+        status: bool = True,
+        outline_color: Tuple[int, int, int] = (255, 255, 255),
+    ):
         blank = Image.new("RGBA", card.size, (255, 255, 255, 0))
 
-        location = tuple(round(x - size / 2) if i <= 1 else round(x + size / 2)
-                         for i, x in enumerate(location + location))
+        location = tuple(
+            round(x - size / 2) if i <= 1 else round(x + size / 2)
+            for i, x in enumerate(location + location)
+        )
 
-        outline_dimensions = tuple(x - outline_thickness if i <= 1 else x + outline_thickness
-                                   for i, x in enumerate(location))
+        outline_dimensions = tuple(
+            x - outline_thickness if i <= 1 else x + outline_thickness
+            for i, x in enumerate(location)
+        )
 
         size_dimensions = (size, size)
         status_dimensions = tuple(round(x / 4) for x in size_dimensions)
@@ -100,32 +110,38 @@ class ImageManager:
         mask = Image.new("RGBA", card.size, 0)
         ImageDraw.Draw(mask).ellipse(location, fill=(255, 25, 255, 255))
 
-        avatar = (await self.convert_image(str(member.avatar_url))).resize(size_dimensions)
+        avatar = (await self.convert_image(str(member.avatar_url))).resize(
+            size_dimensions
+        )
         profile_pic_holder = Image.new("RGBA", card.size, (255, 255, 255, 255))
 
         ImageDraw.Draw(card).ellipse(outline_dimensions, fill=outline_color)
 
         profile_pic_holder.paste(avatar, location)
         pre_card = Image.composite(profile_pic_holder, card, mask)
-        pre_card = pre_card.convert('RGBA')
+        pre_card = pre_card.convert("RGBA")
 
         if status:
             status_picture = Image.open(self.load_asset(f"{member.status.name}.png"))
             status_picture = status_picture.convert("RGBA").resize(status_dimensions)
 
-            blank.paste(status_picture, tuple(x - status_dimensions[0] for x in location[2:]))
+            blank.paste(
+                status_picture, tuple(x - status_dimensions[0] for x in location[2:])
+            )
 
         return Image.alpha_composite(pre_card, blank)
 
-    async def create_welcome_card(self,
-                                  member: discord.Member,
-                                  background: Backgrounds,
-                                  text_color: Tuple[int, int, int],
-                                  title: str,
-                                  description: str,
-                                  font_path: str = None,
-                                  outline: int = 5,
-                                  transparency: int = 0):
+    async def create_welcome_card(
+        self,
+        member: discord.Member,
+        background: Backgrounds,
+        text_color: Tuple[int, int, int],
+        title: str,
+        description: str,
+        font_path: str = None,
+        outline: int = 5,
+        transparency: int = 0,
+    ) -> discord.File:
         result_bytes = BytesIO()
 
         card = Image.open(background.value).resize((1024, 500))
@@ -135,22 +151,26 @@ class ImageManager:
         big_font = ImageFont.truetype(font_path, 36)
         small_font = ImageFont.truetype(font_path, 30)
 
-        draw = ImageDraw.Draw(card, 'RGBA')
+        draw = ImageDraw.Draw(card, "RGBA")
         draw.rectangle((30, 30, 994, 470), fill=(0, 0, 0, transparency))
         draw.text((512, 360), title, text_color, font=big_font, anchor="ms")
         self.multiline_text(card, description, small_font, text_color, 380, 60)
 
-        final_card = await self.draw_profile_picture(card, member, (512, 180), 260, outline_thickness=outline)
+        final_card = await self.draw_profile_picture(
+            card, member, (512, 180), 260, outline_thickness=outline
+        )
 
         final_card.save(result_bytes, format="PNG")
         result_bytes.seek(0)
         return discord.File(result_bytes, filename="welcome_card.png")
 
-    async def merge_image(self,
-                          foreground: str,
-                          background: str,
-                          blend_level: float = 0.6,
-                          discord_file: bool = True) -> Union[discord.File, Image]:
+    async def merge_image(
+        self,
+        foreground: str,
+        background: str,
+        blend_level: float = 0.6,
+        discord_file: bool = True,
+    ) -> Union[discord.File, Image]:
         """Merges two images together"""
         foreground = await self.convert_image(foreground)
         background = await self.convert_image(background)
@@ -167,14 +187,16 @@ class ImageManager:
 
         return result
 
-    async def create_leveling_profile(self,
-                                      member: discord.Member,
-                                      member_account: LevelingAccount,
-                                      background: Backgrounds,
-                                      text_color: Tuple[int, int, int],
-                                      rank: int,
-                                      font_path: str = None,
-                                      outline: int = 5) -> discord.File:
+    async def create_leveling_profile(
+        self,
+        member: discord.Member,
+        member_account: LevelingAccount,
+        background: Backgrounds,
+        text_color: Tuple[int, int, int],
+        rank: int,
+        font_path: str = None,
+        outline: int = 5,
+    ) -> discord.File:
         result_bytes = BytesIO()
 
         card = Image.open(background.value).resize((850, 238))
@@ -186,23 +208,37 @@ class ImageManager:
         draw = ImageDraw.Draw(card)
         draw.text((245, 90), str(member), text_color, font=font_big, anchor="ls")
         draw.text((800, 90), f"Rank #{rank}", text_color, font=font_big, anchor="rs")
-        draw.text((245, 165), f"Level {await member_account.level()}", text_color, font=font_small, anchor="ls")
-        draw.text((800, 165),
-                  f"{self.human_format(await member_account.xp())} /"
-                  f" {self.human_format(await member_account.next_level())} XP",
-                  text_color,
-                  font=font_small,
-                  anchor="rs")
+        draw.text(
+            (245, 165),
+            f"Level {await member_account.level()}",
+            text_color,
+            font=font_small,
+            anchor="ls",
+        )
+        draw.text(
+            (800, 165),
+            f"{self.human_format(await member_account.xp())} /"
+            f" {self.human_format(await member_account.next_level())} XP",
+            text_color,
+            font=font_small,
+            anchor="rs",
+        )
 
-        draw.rounded_rectangle((245, 185, 800, 205), fill=(0, 0, 0, 0), outline=text_color, radius=10)
+        draw.rounded_rectangle(
+            (245, 185, 800, 205), fill=(0, 0, 0, 0), outline=text_color, radius=10
+        )
         length_of_bar = await member_account.percentage_next_level() * 5.5 + 250
-        draw.rounded_rectangle((245, 185, length_of_bar, 205), fill=text_color, radius=10)
+        draw.rounded_rectangle(
+            (245, 185, length_of_bar, 205), fill=text_color, radius=10
+        )
 
-        final_card = await self.draw_profile_picture(card,
-                                                     member,
-                                                     (109, 119),
-                                                     outline_thickness=outline,
-                                                     outline_color=text_color)
+        final_card = await self.draw_profile_picture(
+            card,
+            member,
+            (109, 119),
+            outline_thickness=outline,
+            outline_color=text_color,
+        )
 
         final_card.save(result_bytes, format="PNG")
         result_bytes.seek(0)
