@@ -26,10 +26,12 @@ class KickManager(EventManager, Punisher):
         super().__init__()
         self.bot = bot
 
-    async def punish(self, ctx: commands.Context, member: discord.Member, punishment: Punishment) -> None:
+    async def punish(
+        self, ctx: commands.Context, member: discord.Member, punishment: Punishment
+    ) -> None:
         try:
             await member.kick(reason=punishment.punishment_reason)
         except discord.errors.Forbidden as e:
             raise e
         else:
-            await self.call_event("on_punishment", ctx, member, punishment)
\ No newline at end of file
+            await self.call_event("on_punishment", ctx, member, punishment)
