@@ -1,31 +1,31 @@
 from __future__ import annotations
 
 import asyncio
+import random
 import re
 import time
 from enum import Enum
-from typing import (
-    Optional,
-    TYPE_CHECKING,
-    Iterable,
-    List,
-    Union,
-    Any
-)
+from typing import Optional, TYPE_CHECKING, Iterable, List, Union, Any, Tuple
 
 import aiohttp
 import discord
-import youtube_dl
 
 from .Base import EventManager
 from .Spotify import SpotifyClient
+from .Youtube import YoutubeClient
 
 if TYPE_CHECKING:
     from discord.ext import commands
 
+FFMPEG_OPTIONS = {
+    "before_options": "-reconnect 1 -reconnect_streamed 1 -reconnect_delay_max 5",
+    "options": "-vn",
+}
+SPOTIFY_RE = re.compile("^https://open.spotify.com/")
+YOUTUBE = YoutubeClient()
+
 __all__ = (
     "NotPlaying",
-    "AlreadyPlaying",
     "NotConnected",
     "NotPaused",
     "QueueEmpty",
@@ -38,7 +38,7 @@ __all__ = (
     "Loops",
     "Player",
     "QueueManager",
-    "MusicManager"
+    "MusicManager",
 )
 
 
@@ -46,10 +46,6 @@ class NotPlaying(Exception):
     """Raises error when client is not playing"""
 
 
-class AlreadyPlaying(Exception):
-    """Raises error when player is already playing"""
-
-
 class NotConnected(Exception):
     """Raises error when client is not connected to a voice channel"""
 
@@ -92,53 +88,115 @@ class Loops(Enum):
     QUEUE_LOOP = 2
 
 
-class Player(discord.PCMVolumeTransformer):
+class Player:
     """
     Represents a music player.
     """
 
-    __slots__ = ("data", "title", "stream_url", "url", "start_timestamp", "last_pause_timestamp", "duration")
-
-    def __init__(self, source, *, data, volume=0.1):
-        super().__init__(source, volume)
+    __slots__ = (
+        "data",
+        "title",
+        "stream_url",
+        "url",
+        "start_timestamp",
+        "last_pause_timestamp",
+        "duration",
+        "requester",
+        "source",
+        "autoplayed",
+    )
 
+    def __init__(self, requester: Optional[discord.Member], data):
+        self.source = None
         self.data = data
-        self.title = data.get('title')
-        self.stream_url = data.get('url')
-        self.url = data.get('webpage_url')
+        self.requester = requester
+        self.title = data["videoDetails"]["title"]
+        self.stream_url = data.get("url")
+        self.url = "https://youtube.com/watch/?v=" + data["videoDetails"]["videoId"]
 
+        self.autoplayed = False
         self.start_timestamp = 0
         self.last_pause_timestamp = 0
 
-        self.duration = data.get('duration') if data.get('duration') != 0 else "LIVE"
+        duration = int(data["videoDetails"]["lengthSeconds"])
+        self.duration = duration if duration != 0 else "LIVE"
 
     def __str__(self):
         return self.title
 
-    @staticmethod
-    async def make_multiple_players(songs: Iterable[str]) -> List[Player]:
+    @classmethod
+    async def make_multiple_players(
+        cls, songs: Iterable[str], requester: Optional[discord.Member]
+    ) -> List[Player]:
         """
         |coro|
 
         Returns a list of players from a iterable of queries.
 
+        :param requester: The requester.
+        :type requester: Optional[discord.Member]
         :param songs: The queries.
         :type songs: Iterable[str]
         :return: The list of created players.
         :rtype: List[Player]
         """
 
-        tasks = [Player.make_player(song, playlist=False) for song in songs]
-        return [x[0] for x in await asyncio.gather(*tasks) if x]
+        tasks = [cls.fetch_song(song, playlist=False) for song in songs]
+
+        songs = await asyncio.gather(*tasks)
+
+        return [cls(requester, data=x[0]) for x in songs if x]
+
+    @staticmethod
+    async def fetch_song(query: str, playlist: bool = True) -> List[dict]:
+        """
+        |coro|
+
+        Fetches the song's or playlist's data.
+        Will return the first song in the playlist if playlist is False.
+
+        :param query: The query.
+        :type query: str
+        :param playlist: A bool indicating if the function should fetch playlists or get the first video.
+        :type playlist: bool
+        :return: The list of songs.
+        :rtype: List[dict]
+        """
+
+        data = await MusicManager.fetch_data(query, playlist)
+        if not data:
+            return []
+
+        players = []
+        for player in data:
+            stream_url = [
+                x
+                for x in sorted(
+                    player["streamingData"]["adaptiveFormats"],
+                    key=lambda x: x.get("averageBitrate", 0),
+                    reverse=True,
+                )
+                if "audio" in x["mimeType"] and "opus" not in x["mimeType"]
+            ]
+            url = player["streamingData"].get("hlsManifestUrl") or stream_url[0]["url"]
+
+            player["url"] = url
+            players.append(
+                {x: y for x, y in player.items() if x in ["url", "videoDetails"]}
+            )
+
+        return players
 
     @classmethod
-    async def make_player(cls, query: str, playlist: bool = True) -> List[Player]:
+    async def make_players(
+        cls, query: str, requester: Optional[discord.Member], playlist: bool = True
+    ) -> List[Player]:
         """
         |coro|
 
         Returns a list of players from the query.
-        The list will contain the first video incase it is not a playlist.
 
+        :param Optional[discord.Member] requester: The song requester.
         :param query: The query.
         :type query: str
         :param playlist: A bool indicating if the function should fetch playlists or get the first video.
@@ -147,29 +205,29 @@ class Player(discord.PCMVolumeTransformer):
         :rtype: List[Player]
         """
 
-        data = await MusicManager.fetch_data(query)
-        if data is None:
-            return []
-
-        if 'entries' in data:
-            if not playlist:
-                data = data['entries'][0]
-            else:
-                return [cls(
-                    discord.FFmpegPCMAudio(player['url'],
-                                           **MusicManager.FFMPEG_OPTIONS), data=player) for player in data['entries']]
-
-        filename = data['url']
-        return [cls(discord.FFmpegPCMAudio(filename, **MusicManager.FFMPEG_OPTIONS), data=data)]
+        return [
+            cls(requester, data=player)
+            for player in await cls.fetch_song(query, playlist)
+        ]
 
 
 class QueueManager:
-    __slots__ = ("queue", "volume", "history", "loop", "now_playing")
+    __slots__ = (
+        "queue",
+        "volume",
+        "history",
+        "loop",
+        "now_playing",
+        "autoplay",
+        "shuffle",
+    )
 
     def __init__(self, volume: float, queue: List[Player]):
         self.queue = queue
         self.volume = volume
         self.history = []
+        self.autoplay = False
+        self.shuffle = False
         self.loop = Loops.NO_LOOP
         self.now_playing = None
 
@@ -207,43 +265,54 @@ class QueueManager:
 
         return self.queue.pop(index)
 
+    def cleanup(self):
+        self.clear()
+        self.history.clear()
+        del self.history
+        del self.queue
+
 
 class MusicManager(EventManager):
     """
     Represents a MusicManager.
     """
 
-    FFMPEG_OPTIONS = {'before_options': '-reconnect 1 -reconnect_streamed 1 -reconnect_delay_max 5', 'options': '-vn'}
-    SPOTIFY_RE = re.compile("^https://open.spotify.com/")
-    YTDL = youtube_dl.YoutubeDL({
-        'format': 'bestaudio/best',
-        'restrictfilenames': True,
-        'noplaylist': False,
-        'nocheckcertificate': True,
-        'ignoreerrors': False,
-        'logtostderr': False,
-        'quiet': True,
-        'no_warnings': True,
-        'default_search': 'auto'
-    })
+    __slots__ = (
+        "bot",
+        "client_id",
+        "client_secret",
+        "spotify_support",
+        "inactivity_timeout",
+        "queue",
+        "spotify",
+    )
 
-    __slots__ = ("bot", "client_id", "client_secret", "spotify_support", "inactivity_timeout", "queue", "spotify")
-
-    def __init__(self, bot: commands.Bot, spotify_support: bool = True, inactivity_timeout: int = 60, **kwargs):
+    def __init__(
+        self,
+        bot: commands.Bot,
+        spotify_support: bool = True,
+        inactivity_timeout: int = 60,
+        **kwargs,
+    ):
         super().__init__()
         self.bot = bot
 
-        self.client_id = kwargs.get('client_id')
-        self.client_secret = kwargs.get('client_secret')
+        self.client_id = kwargs.get("client_id")
+        self.client_secret = kwargs.get("client_secret")
         self.spotify_support = spotify_support
         self.inactivity_timeout = inactivity_timeout
 
         self.queue = {}
 
+        self.youtube = YoutubeClient()
         if spotify_support:
-            self.spotify = SpotifyClient(client_id=self.client_id, client_secret=self.client_secret)
+            self.spotify = SpotifyClient(
+                client_id=self.client_id,
+                client_secret=self.client_secret,
+                loop=self.bot.loop,
+            )
 
-    async def __ensure_activity(self, ctx: commands.Context) -> None:
+    async def ensure_activity(self, ctx: commands.Context) -> None:
         """
         |coro|
 
@@ -268,10 +337,12 @@ class MusicManager(EventManager):
             await ctx.voice_client.disconnect()
             await self.call_event("on_inactivity_disconnect", ctx)
 
-    async def __check_connection(self,
-                                 ctx: commands.Context,
-                                 check_playing: bool = False,
-                                 check_queue: bool = False) -> Optional[bool]:
+    async def __check_connection(
+        self,
+        ctx: commands.Context,
+        check_playing: bool = False,
+        check_queue: bool = False,
+    ) -> Optional[bool]:
         """
         |coro|
 
@@ -288,27 +359,56 @@ class MusicManager(EventManager):
         """
 
         if not ctx.voice_client or not ctx.voice_client.is_connected():
-            await self.call_event('on_music_error', ctx, NotConnected("Client is not connected to a voice channel"))
+            await self.call_event(
+                "on_music_error",
+                ctx,
+                NotConnected("Client is not connected to a voice channel"),
+            )
             return
 
         if check_playing and not ctx.voice_client.is_playing():
-            await self.call_event('on_music_error', ctx, NotPlaying("Client is not playing anything currently"))
+            await self.call_event(
+                "on_music_error",
+                ctx,
+                NotPlaying("Client is not playing anything currently"),
+            )
             return
 
         if check_queue and ctx.guild.id not in self.queue:
-            await self.call_event('on_music_error', ctx, QueueEmpty("Queue is empty"))
+            await self.call_event("on_music_error", ctx, QueueEmpty("Queue is empty"))
             return
 
         return True
 
+    @staticmethod
+    async def _get_similar_videos(video_id: str) -> List[Player]:
+        """
+        |coro|
+
+        Creates similar videos related to the video id.
+
+        :param str video_id: The video id
+        :return: The list of similar players
+        :rtype: List[Player]
+        """
+
+        similar_video = await YOUTUBE.get_similar_videos(video_id)
+        players = await Player.make_players(
+            f"https://youtube.com/watch/?v={similar_video[0]}", None, False
+        )
+        for player in players:
+            player.autoplayed = True
+
+        return players
+
     async def __check_queue(self, ctx: commands.Context) -> None:
         """
         |coro|
 
-        Plays the next song in the queue, handles looping and queue looping.
+        Plays the next song in the queue, handles looping, queue looping, autoplay, etc.
 
         :param ctx: The context of the voice client.
-        :type ctx: commands.Contet
+        :type ctx: commands.Context
         :return: None
         :rtype: None
         """
@@ -317,38 +417,57 @@ class MusicManager(EventManager):
             if not ctx.voice_client or not ctx.voice_client.is_connected():
                 return
 
-            if self.queue[ctx.guild.id].loop == Loops.LOOP:
-                song = self.queue[ctx.guild.id].now_playing
-                player = (await Player.make_player(song.url, playlist=False))[0]
+            queue = self.queue[ctx.guild.id]
 
-            elif self.queue[ctx.guild.id].loop == Loops.QUEUE_LOOP:
-                song = self.queue[ctx.guild.id].remove(0)
-                player = (await Player.make_player(song.url, playlist=False))[0]
+            if queue.loop == Loops.LOOP:
+                player = queue.now_playing
+
+            elif queue.loop == Loops.QUEUE_LOOP:
+                player = (
+                    random.choice(queue.queue) if queue.shuffle else queue.remove(0)
+                )
                 self.queue[ctx.guild.id].add(player)
 
             else:
-                player = self.queue[ctx.guild.id].remove(0)
+                if not queue.queue and queue.autoplay:
+                    last_video_id = queue.history[-1].data["videoDetails"]["videoId"]
+                    player = (await self._get_similar_videos(last_video_id))[0]
 
-            self.queue[ctx.guild.id].now_playing = player
+                else:
+                    player = (
+                        random.choice(queue.queue) if queue.shuffle else queue.remove(0)
+                    )
+
+            player.source = discord.PCMVolumeTransformer(
+                discord.FFmpegPCMAudio(player.stream_url, **FFMPEG_OPTIONS),
+                queue.volume,
+            )
+
+            queue.now_playing = player
 
             if player is None or not ctx.voice_client:
                 return
 
-            player.volume = self.queue[ctx.guild.id].volume
-            ctx.voice_client.play(player, after=lambda x: self.bot.loop.create_task(self.__check_queue(ctx)))
+            ctx.voice_client.play(
+                player.source,
+                after=lambda x: self.bot.loop.create_task(self.__check_queue(ctx)),
+            )
             player.start_timestamp = time.time()
 
-            if self.queue[ctx.guild.id].loop == Loops.NO_LOOP:
-                self.queue[ctx.guild.id].history.append(player)
-                await self.call_event('on_play', ctx, player)
+            if queue.loop == Loops.NO_LOOP:
+                queue.history.append(player)
+                await self.call_event("on_play", ctx, player)
 
         except (IndexError, KeyError):
             if ctx.guild.id in self.queue:
-                self.queue[ctx.guild.id].now_playing = None
+                self.queue[ctx.guild.id].cleanup()
+                del self.queue[ctx.guild.id]
 
             await self.call_event("on_queue_end", ctx)
 
-    async def get_player_played_duration(self, ctx: commands.Context, player: Player) -> Optional[float]:
+    async def get_player_played_duration(
+        self, ctx: commands.Context, player: Player
+    ) -> Optional[float]:
         """
         |coro|
 
@@ -367,49 +486,64 @@ class MusicManager(EventManager):
 
         start_timestamp = player.start_timestamp
         if ctx.voice_client.is_paused():
-            start_timestamp = player.start_timestamp + time.time() - player.last_pause_timestamp
+            start_timestamp = (
+                player.start_timestamp + time.time() - player.last_pause_timestamp
+            )
 
         time_played = time.time() - start_timestamp
-        return min(time_played, time_played if player.duration == "LIVE" else player.duration)
+        return min(
+            time_played, time_played if player.duration == "LIVE" else player.duration
+        )
 
     @staticmethod
-    async def fetch_data(query: str) -> Optional[dict]:
+    async def fetch_data(query: str, playlist: bool = True) -> List[dict]:
         """
         |coro|
 
-        Fetches the YTDL data of the query.
+        Fetches the youtube data of the query.
 
+        :param bool playlist: Indicating if it should fetch playlists.
         :param query: The query.
         :type query: str
-        :return: The YTDL data.
+        :return: The youtube data.
         :rtype: Optional[dict]
         """
 
-        try:
-            loop = asyncio.get_event_loop()
-            return await loop.run_in_executor(None, lambda: MusicManager.YTDL.extract_info(query, download=False))
-        except youtube_dl.utils.DownloadError:
-            return None
+        return [
+            x
+            for x in await YOUTUBE.get_videos(
+                await YOUTUBE.get_query_id(query), playlist
+            )
+            if "streamingData" in x
+        ]
 
-    async def create_player(self, query: str) -> List[Player]:
+    async def create_player(
+        self, query: str, requester: discord.Member
+    ) -> List[Player]:
         """
         |coro|
 
         Creates a list of players from the query.
         This function supports Spotify and all YTDL supported links.
 
+        :param requester: The requester.
+        :type requester: discord.Member
         :param query: The query.
         :type query: str
         :return: The list of players.
         :rtype: List[Player]
         """
 
-        if self.SPOTIFY_RE.match(query) and self.spotify_support:
-            return await Player.make_multiple_players([song for song in await self.spotify.get_songs(query)])
+        if SPOTIFY_RE.match(query) and self.spotify_support:
+            return await Player.make_multiple_players(
+                [song for song in await self.spotify.get_songs(query)], requester
+            )
 
-        return await Player.make_player(query)
+        return await Player.make_players(query, requester)
 
-    async def queue_add(self, players: List[Player], ctx: commands.Context) -> None:
+    async def queue_add(
+        self, players: List[Player], ctx: commands.Context
+    ) -> Optional[bool]:
         """
         |coro|
 
@@ -420,8 +554,8 @@ class MusicManager(EventManager):
         :type players: List[Player]
         :param ctx: The context.
         :type ctx: commands.Context
-        :return: None
-        :rtype: None
+        :return: A bool indicating if it was successful
+        :rtype: Optional[bool]
         """
 
         if not await self.__check_connection(ctx):
@@ -432,6 +566,8 @@ class MusicManager(EventManager):
         else:
             self.queue[ctx.guild.id] = QueueManager(0.1, players)
 
+        return True
+
     async def queue_remove(self, ctx: commands.Context, index: int) -> None:
         """
         |coro|
@@ -453,9 +589,15 @@ class MusicManager(EventManager):
         try:
             self.queue[ctx.guild.id].remove(index)
         except IndexError:
-            await self.call_event('on_music_error', ctx, QueueError("Failure when removing player from queue"))
+            await self.call_event(
+                "on_music_error",
+                ctx,
+                QueueError("Failure when removing player from queue"),
+            )
 
-    async def lyrics(self, ctx: commands.Context, query: str = None) -> Optional[str]:
+    async def lyrics(
+        self, ctx: commands.Context, query: str = None
+    ) -> Optional[Tuple[str, str, str]]:
         """
         |coro|
 
@@ -465,20 +607,29 @@ class MusicManager(EventManager):
         :type ctx: commands.Context
         :param query: The query.
         :type query: str
-        :return: The lyrics.
-        :rtype: Optional[str]
+        :return: The lyrics and the song name.
+        :rtype: Optional[Tuple[str, str, str]]
         """
 
         query = await self.now_playing(ctx) if query is None else query
+        if not query:
+            return
+
         url = f"https://some-random-api.ml/lyrics?title={query}"
 
         async with aiohttp.ClientSession() as session:
             request = await session.get(url)
             request_json = await request.json()
 
-            return request_json.get('lyrics', None)
+            authors = request_json.get("author")
+            title = request_json.get("title")
+            lyrics = request_json.get("lyrics")
 
-    async def play(self, ctx: commands.Context, player: Player = None) -> Optional[bool]:
+            return (title, authors, lyrics) if lyrics else None
+
+    async def play(
+        self, ctx: commands.Context, player: Player = None
+    ) -> Optional[bool]:
         """
         |coro|
 
@@ -496,7 +647,7 @@ class MusicManager(EventManager):
             return
 
         if player is not None:
-            ctx.voice_client.play(player)
+            ctx.voice_client.play(player.source)
             return True
 
         if not ctx.voice_client.is_playing():
@@ -520,12 +671,14 @@ class MusicManager(EventManager):
             return
 
         if ctx.voice_client.is_paused():
-            await self.call_event('on_music_error', ctx, AlreadyPaused("Player is already paused."))
+            await self.call_event(
+                "on_music_error", ctx, AlreadyPaused("Player is already paused.")
+            )
             return
 
         (await self.now_playing(ctx)).last_pause_timestamp = time.time()
         ctx.voice_client.pause()
-        self.bot.loop.create_task(self.__ensure_activity(ctx))
+        self.bot.loop.create_task(self.ensure_activity(ctx))
         return True
 
     async def resume(self, ctx: commands.Context) -> Optional[bool]:
@@ -545,7 +698,9 @@ class MusicManager(EventManager):
             return
 
         if not ctx.voice_client.is_paused():
-            await self.call_event('on_music_error', ctx, NotPaused("Player is not paused"))
+            await self.call_event(
+                "on_music_error", ctx, NotPaused("Player is not paused")
+            )
             return
 
         ctx.voice_client.resume()
@@ -573,29 +728,44 @@ class MusicManager(EventManager):
         if not await self.__check_connection(ctx, True, check_queue=True):
             return
 
+        queue = self.queue[ctx.guild.id]
+
         # Created duplicate to make sure InvalidSkipIndex isn't raised when the user does pass an index and the queue
         # is empty.
         skip_index = 0 if index is None else index - 1
-        if not -1 < skip_index < len(self.queue[ctx.guild.id].queue):
+        if not -1 < skip_index < len(queue.queue):
             if index:
-                await self.call_event('on_music_error', ctx, InvalidSkipIndex("Skip index invalid."))
+                await self.call_event(
+                    "on_music_error", ctx, InvalidSkipIndex("Skip index invalid.")
+                )
                 return
 
-        if len(self.queue[ctx.guild.id].queue) <= skip_index:
-            await self.call_event('on_music_error', ctx, SkipError("No song to skip to."))
+        if not queue.autoplay and len(queue.queue) <= skip_index:
+            await self.call_event(
+                "on_music_error", ctx, SkipError("No song to skip to.")
+            )
+            return
 
         if skip_index > 0:
-            removed_songs = self.queue[ctx.guild.id].queue[:skip_index]
+            removed_songs = queue.queue[:skip_index]
 
-            self.queue[ctx.guild.id].queue = self.queue[ctx.guild.id].queue[skip_index:]
-            if self.queue[ctx.guild.id].loop == Loops.QUEUE_LOOP:
-                self.queue[ctx.guild.id].queue += removed_songs
+            queue.queue = queue.queue[skip_index:]
+            if queue.loop == Loops.QUEUE_LOOP:
+                queue.queue += removed_songs
+
+        if queue.autoplay:
+            last_video_id = queue.history[-1].data["videoDetails"]["videoId"]
+            player = (await self._get_similar_videos(last_video_id))[0]
+            queue.add(player)
+        else:
+            player = queue.queue[0]
 
-        player = self.queue[ctx.guild.id].queue[0]
         ctx.voice_client.stop()
         return player
 
-    async def volume(self, ctx: commands.Context, volume: int = None) -> Optional[float]:
+    async def volume(
+        self, ctx: commands.Context, volume: int = None
+    ) -> Optional[float]:
         """
         |coro|
 
@@ -620,7 +790,7 @@ class MusicManager(EventManager):
         self.queue[ctx.guild.id].volume = volume / 100
         return ctx.voice_client.source.volume * 100
 
-    async def join(self, ctx: commands.Context) -> Optional[bool]:
+    async def join(self, ctx: commands.Context) -> Optional[discord.VoiceChannel]:
         """
         |coro|
 
@@ -629,23 +799,31 @@ class MusicManager(EventManager):
 
         :param ctx: The context.
         :type ctx: commands.Context
-        :return: A bool indicating if the join was successful.
-        :rtype: Optional[bool]
+        :return: The voice channel it joined.
+        :rtype: Optional[discord.VoiceChannel]
         """
 
         if ctx.voice_client and ctx.voice_client.is_connected():
-            await self.call_event('on_music_error', ctx,
-                                  AlreadyConnected("Client is already connected to a voice channel"))
+            await self.call_event(
+                "on_music_error",
+                ctx,
+                AlreadyConnected("Client is already connected to a voice channel"),
+            )
             return
 
         if not ctx.author.voice:
-            await self.call_event('on_music_error', ctx, UserNotConnected("User is not connected to a voice channel"))
+            await self.call_event(
+                "on_music_error",
+                ctx,
+                UserNotConnected("User is not connected to a voice channel"),
+            )
             return
 
-        await ctx.author.voice.channel.connect()
-        return True
+        channel = ctx.author.voice.channel
+        await channel.connect()
+        return channel
 
-    async def leave(self, ctx: commands.Context) -> Optional[bool]:
+    async def leave(self, ctx: commands.Context) -> Optional[discord.VoiceChannel]:
         """
         |coro|
 
@@ -653,32 +831,20 @@ class MusicManager(EventManager):
 
         :param ctx: The context.
         :type ctx: commands.Context
-        :return: A bool indicating if the disconnection was successful.
-        :rtype: Optional[bool]
+        :return: The voice channel it left.
+        :rtype: Optional[discord.VoiceChannel]
         """
 
         if not await self.__check_connection(ctx):
             return
 
+        if ctx.guild.id in self.queue:
+            self.queue[ctx.guild.id].cleanup()
+            del self.queue[ctx.guild.id]
+
+        channel = ctx.voice_client.channel
         await ctx.voice_client.disconnect()
-        return True
-
-    async def history(self, ctx: commands.Context) -> Optional[List[Player]]:
-        """
-        |coro|
-
-        Returns a list of the played players.
-
-        :param ctx: The context.
-        :type ctx: commands.Context
-        :return: A list of played players.
-        :rtype: Optional[List[Player]]
-        """
-
-        if not await self.__check_connection(ctx, check_queue=True):
-            return
-
-        return self.queue[ctx.guild.id].history
+        return channel
 
     async def now_playing(self, ctx: commands.Context) -> Optional[Player]:
         """
@@ -696,8 +862,12 @@ class MusicManager(EventManager):
             return
 
         now_playing = self.queue[ctx.guild.id].now_playing
-        if not now_playing and not ctx.voice_client.is_paused():
-            await self.call_event('on_music_error', ctx, NotPlaying("Client is not playing anything currently"))
+        if not ctx.voice_client.is_playing() and not ctx.voice_client.is_paused():
+            await self.call_event(
+                "on_music_error",
+                ctx,
+                NotPlaying("Client is not playing anything currently"),
+            )
 
         return now_playing
 
@@ -716,14 +886,51 @@ class MusicManager(EventManager):
         if not await self.__check_connection(ctx, check_playing=True, check_queue=True):
             return
 
-        self.queue[ctx.guild.id].loop = Loops.QUEUE_LOOP if self.queue[ctx.guild.id].loop != Loops.QUEUE_LOOP else \
-            Loops.NO_LOOP
+        self.queue[ctx.guild.id].loop = (
+            Loops.QUEUE_LOOP
+            if self.queue[ctx.guild.id].loop != Loops.QUEUE_LOOP
+            else Loops.NO_LOOP
+        )
 
         if self.queue[ctx.guild.id].loop == Loops.QUEUE_LOOP:
             self.queue[ctx.guild.id].add(self.queue[ctx.guild.id].now_playing)
 
         return self.queue[ctx.guild.id].loop == Loops.QUEUE_LOOP
 
+    async def shuffle(self, ctx: commands.Context) -> Optional[bool]:
+        """
+        |coro|
+
+        Toggles the shuffle feature.
+
+        :param commands.Context ctx: The context
+        :return: A bool indicating if the queue loop is now enabled or disabled.
+        :rtype: Optional[bool]
+        """
+
+        if not await self.__check_connection(ctx, check_playing=True, check_queue=True):
+            return
+
+        self.queue[ctx.guild.id].shuffle = not self.queue[ctx.guild.id].shuffle
+        return self.queue[ctx.guild.id].shuffle
+
+    async def autoplay(self, ctx: commands.Context) -> Optional[bool]:
+        """
+        |coro|
+
+        Toggles the autoplay feature.
+
+        :param commands.Context ctx: The context
+        :return: A bool indicating if autoplay is now enabled or disabled.
+        :rtype: Optional[bool]
+        """
+
+        if not await self.__check_connection(ctx, check_playing=True, check_queue=True):
+            return
+
+        self.queue[ctx.guild.id].autoplay = not self.queue[ctx.guild.id].autoplay
+        return self.queue[ctx.guild.id].autoplay
+
     async def loop(self, ctx: commands.Context) -> Optional[bool]:
         """
         |coro|
@@ -739,10 +946,12 @@ class MusicManager(EventManager):
         if not await self.__check_connection(ctx, check_playing=True, check_queue=True):
             return
 
-        self.queue[ctx.guild.id].loop = Loops.LOOP if self.queue[ctx.guild.id].loop != Loops.LOOP else Loops.NO_LOOP
+        self.queue[ctx.guild.id].loop = (
+            Loops.LOOP if self.queue[ctx.guild.id].loop != Loops.LOOP else Loops.NO_LOOP
+        )
         return self.queue[ctx.guild.id].loop == Loops.LOOP
 
-    async def get_queue(self, ctx: commands.Context) -> Optional[List[Player]]:
+    async def get_queue(self, ctx: commands.Context) -> Optional[QueueManager]:
         """
         |coro|
 
@@ -751,24 +960,10 @@ class MusicManager(EventManager):
         :param ctx: The context.
         :type ctx: commands.Context
         :return: The queue.
-        :rtype: Optional[List[Player]]
+        :rtype: Optional[QueueManager]
         """
 
         if not await self.__check_connection(ctx, check_queue=True):
             return
 
-        return self.queue[ctx.guild.id].queue
-
-    async def clear_queue(self, ctx: commands.Context) -> None:
-        """
-        |coro|
-
-        Clears the ctx's guild's Queue
-
-        :parameter ctx: Context object to fetch the guild from
-        :type ctx: commands.Context
-        :return: None
-        :rtype: None
-        """
-
-        self.queue[ctx.guild.id].clear()
+        return self.queue[ctx.guild.id]
